package com.ruoyi.web.controller.cp;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CpsMeetingEnterprise;
import com.ruoyi.system.service.ICpsMeetingEnterpriseService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cps_meeting_enterprise 与会企业Controller
 *
 * @author ruoyi
 * @date 2024-08-14
 */
@RestController
@RequestMapping("/cp/enterprise")
public class CpsMeetingEnterpriseController extends BaseController
{
    @Autowired
    private ICpsMeetingEnterpriseService cpsMeetingEnterpriseService;

    /**
     * 查询cps_meeting_enterprise 与会企业列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CpsMeetingEnterprise cpsMeetingEnterprise)
    {
        startPage();
        List<CpsMeetingEnterprise> list = cpsMeetingEnterpriseService.selectCpsMeetingEnterpriseList(cpsMeetingEnterprise);
        return getDataTable(list);
    }

    /**
     * 导出cps_meeting_enterprise 与会企业列表
     */
    @Log(title = "cps_meeting_enterprise 与会单位", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CpsMeetingEnterprise cpsMeetingEnterprise)
    {
        List<CpsMeetingEnterprise> list = cpsMeetingEnterpriseService.selectCpsMeetingEnterpriseList(cpsMeetingEnterprise);
        ExcelUtil<CpsMeetingEnterprise> util = new ExcelUtil<CpsMeetingEnterprise>(CpsMeetingEnterprise.class);
        util.exportExcel(response, list, "cps_meeting_enterprise 与会单位数据");
    }

    /**
     * 获取cps_meeting_enterprise 与会企业详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(cpsMeetingEnterpriseService.selectCpsMeetingEnterpriseById(id));
    }

    /**
     * 新增cps_meeting_enterprise 与会企业
     */
    @Log(title = "cps_meeting_enterprise 与会企业", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CpsMeetingEnterprise cpsMeetingEnterprise)
    {
        return toAjax(cpsMeetingEnterpriseService.insertCpsMeetingEnterprise(cpsMeetingEnterprise));
    }

    /**
     * 修改cps_meeting_enterprise 与会企业
     */
    @Log(title = "cps_meeting_enterprise 与会企业", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CpsMeetingEnterprise cpsMeetingEnterprise)
    {
        return toAjax(cpsMeetingEnterpriseService.updateCpsMeetingEnterprise(cpsMeetingEnterprise));
    }

    /**
     * 删除cps_meeting_enterprise 与会企业
     */
    @Log(title = "cps_meeting_enterprise 与会企业", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(cpsMeetingEnterpriseService.deleteCpsMeetingEnterpriseByIds(ids));
    }
}
