package com.ruoyi.web.controller.cp;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.CpsMeetingEnterpriseTripInfo;
import com.ruoyi.system.service.ICpsMeetingEnterpriseTripInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * cps_meeting_enterprise_trip_info与会企业行程信息Controller
 *
 * @author ruoyi
 * @date 2024-08-14
 */
@RestController
@RequestMapping("/cp/enterpriseTripInfo")
public class CpsMeetingEnterpriseTripInfoController extends BaseController
{
    @Autowired
    private ICpsMeetingEnterpriseTripInfoService cpsMeetingEnterpriseTripInfoService;

    /**
     * 查询cps_meeting_enterprise_trip_info与会企业行程信息列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CpsMeetingEnterpriseTripInfo cpsMeetingEnterpriseTripInfo)
    {
        startPage();
        List<CpsMeetingEnterpriseTripInfo> list = cpsMeetingEnterpriseTripInfoService.selectCpsMeetingEnterpriseTripInfoList(cpsMeetingEnterpriseTripInfo);
        return getDataTable(list);
    }

    /**
     * 导出cps_meeting_enterprise_trip_info与会企业行程信息列表
     */
    @Log(title = "cps_meeting_enterprise_trip_info与会企业行程信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CpsMeetingEnterpriseTripInfo cpsMeetingEnterpriseTripInfo)
    {
        List<CpsMeetingEnterpriseTripInfo> list = cpsMeetingEnterpriseTripInfoService.selectCpsMeetingEnterpriseTripInfoList(cpsMeetingEnterpriseTripInfo);
        ExcelUtil<CpsMeetingEnterpriseTripInfo> util = new ExcelUtil<CpsMeetingEnterpriseTripInfo>(CpsMeetingEnterpriseTripInfo.class);
        util.exportExcel(response, list, "cps_meeting_enterprise_trip_info与会单位行程信息数据");
    }

    /**
     * 获取cps_meeting_enterprise_trip_info与会企业行程信息详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(cpsMeetingEnterpriseTripInfoService.selectCpsMeetingEnterpriseTripInfoById(id));
    }

    /**
     * 新增cps_meeting_enterprise_trip_info与会企业行程信息
     */
    @Log(title = "cps_meeting_enterprise_trip_info与会企业行程信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CpsMeetingEnterpriseTripInfo cpsMeetingEnterpriseTripInfo)
    {
        return toAjax(cpsMeetingEnterpriseTripInfoService.insertCpsMeetingEnterpriseTripInfo(cpsMeetingEnterpriseTripInfo));
    }

    /**
     * 修改cps_meeting_enterprise_trip_info与会企业行程信息
     */
    @Log(title = "cps_meeting_enterprise_trip_info与会企业行程信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CpsMeetingEnterpriseTripInfo cpsMeetingEnterpriseTripInfo)
    {
        return toAjax(cpsMeetingEnterpriseTripInfoService.updateCpsMeetingEnterpriseTripInfo(cpsMeetingEnterpriseTripInfo));
    }

    /**
     * 删除cps_meeting_enterprise_trip_info与会企业行程信息
     */
    @Log(title = "cps_meeting_enterprise_trip_info与会企业行程信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(cpsMeetingEnterpriseTripInfoService.deleteCpsMeetingEnterpriseTripInfoByIds(ids));
    }
}
