package com.ruoyi.system.service.impl;

import com.alibaba.fastjson2.JSON;
import com.ruoyi.common.config.AppCfg;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.core.domain.model.WeChatUser;
import com.ruoyi.common.enums.MeetingType;
import com.ruoyi.common.enums.ReviewStatus;
import com.ruoyi.common.enums.SysYesNo;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.bean.BeanValidators;
import com.ruoyi.system.domain.CpsContentInfo;
import com.ruoyi.system.domain.CpsMeetingEnterpriseTripInfo;
import com.ruoyi.system.domain.CpsMeetingUsr;
import com.ruoyi.system.domain.CpsUsrApply;
import com.ruoyi.system.mapper.CpsContentInfoMapper;
import com.ruoyi.system.mapper.CpsMeetingEnterpriseTripInfoMapper;
import com.ruoyi.system.mapper.CpsMeetingUsrMapper;
import com.ruoyi.system.mapper.CpsUsrApplyMapper;
import com.ruoyi.system.service.ICpsMeetingUsrService;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.validation.Validator;
import java.util.List;
import java.util.concurrent.ScheduledExecutorService;

/**
 * cps_usr_wechat微信用户Service业务层处理
 *
 * @author ruoyi
 * @date 2024-08-18
 */
@Service
public class CpsMeetingUsrServiceImpl implements ICpsMeetingUsrService {
    private static final Logger log = LoggerFactory.getLogger(CpsMeetingUsrServiceImpl.class);

    @Autowired
    private CpsMeetingUsrMapper cpsMeetingUsrMapper;

    @Autowired
    private CpsMeetingEnterpriseTripInfoMapper cpsMeetingTripService;

    @Autowired
    private CpsUsrApplyMapper cpsUsrApplyMapper;

    @Autowired
    private CpsContentInfoMapper contentInfoMapper;

    @Autowired
    private ScheduledExecutorService executor;

    @Autowired
    private AppCfg appCfg;


    @Autowired
    protected Validator validator;

    /**
     * 查询cps_usr_wechat微信用户
     *
     * @param id cps_usr_wechat微信用户主键
     * @return cps_usr_wechat微信用户
     */
    @Override
    public CpsMeetingUsr selectCpsMeetingUsrById(Long id) {
        return cpsMeetingUsrMapper.selectCpsMeetingUsrById(id);
    }

    /**
     * 查询cps_usr_wechat微信用户列表
     *
     * @param cpsMeetingUsr cps_usr_wechat微信用户
     * @return cps_usr_wechat微信用户
     */
    @Override
    public List<CpsMeetingUsr> selectCpsMeetingUsrList(CpsMeetingUsr cpsMeetingUsr) {
        return cpsMeetingUsrMapper.selectCpsMeetingUsrList(cpsMeetingUsr);
    }

    /**
     * 新增cps_usr_wechat微信用户
     *
     * @param cpsMeetingUsr cps_usr_wechat微信用户
     * @return 结果
     */
    @Override
    public int insertCpsMeetingUsr(CpsMeetingUsr cpsMeetingUsr) {
        cpsMeetingUsr.setCreateTime(DateUtils.getNowDate());
        return cpsMeetingUsrMapper.insertCpsMeetingUsr(cpsMeetingUsr);
    }

    /**
     * 修改cps_usr_wechat微信用户
     *
     * @param cpsMeetingUsr cps_usr_wechat微信用户
     * @return 结果
     */
    @Override
    public int updateCpsMeetingUsr(CpsMeetingUsr cpsMeetingUsr) {
        cpsMeetingUsr.setUpdateTime(DateUtils.getNowDate());
        return cpsMeetingUsrMapper.updateCpsMeetingUsr(cpsMeetingUsr);
    }

    /**
     * 批量删除cps_usr_wechat微信用户
     *
     * @param ids 需要删除的cps_usr_wechat微信用户主键
     * @return 结果
     */
    @Override
    public int deleteCpsMeetingUsrByIds(Long[] ids) {
        return cpsMeetingUsrMapper.deleteCpsMeetingUsrByIds(ids);
    }

    /**
     * 删除cps_usr_wechat微信用户信息
     *
     * @param id cps_usr_wechat微信用户主键
     * @return 结果
     */
    @Override
    public int deleteCpsMeetingUsrById(Long id) {
        return cpsMeetingUsrMapper.deleteCpsMeetingUsrById(id);
    }

    @Override
    public Boolean existCpsMeetingUsr(String tel) {
        return cpsMeetingUsrMapper.exitUser(tel) > 0;
    }

    @Override
    public CpsMeetingUsr getWeChatUser(WeChatUser wxUser) {
        if (!existCpsMeetingUsr(wxUser.getTel())) {
            CpsMeetingUsr cpsMeetingUsr = new CpsMeetingUsr() {{
                setUsrName(wxUser.getNickName());
                setOpenId(wxUser.getOpenid());
                setTel(wxUser.getTel());
                setAvatarUrl(wxUser.getAvatarUrl());
            }};
            insertCpsMeetingUsr(cpsMeetingUsr);
            return cpsMeetingUsr;
        }
        return selectCpsMeetingUsrList(new CpsMeetingUsr() {{
            setTel(wxUser.getTel());
        }}).get(0);
    }

    @Override
    public void usrThemeConferenceRegister(CpsUsrApply user, String type) {
        List<CpsUsrApply> cpsUsrApplies = cpsUsrApplyMapper.selectCpsUsrApplyList(new CpsUsrApply() {{
            setTel(user.getTel());
            setApplyType(type);
            setReviewState(ReviewStatus.PASS.getCode());
        }});
        if (CollectionUtils.isNotEmpty(cpsUsrApplies)) {
            throw new ServiceException("该手机号已经报名，请勿反复报名");
        }
        user.setReviewState(ReviewStatus.WAIT.getCode());
        user.setApplyType(type);
        user.setReviewMsg("");
        WeChatUser loginUser = (WeChatUser) SecurityUtils.getLoginUser();
        user.setUpdateBy(loginUser.getOpenid());
        CpsContentInfo cpsContentInfo = contentInfoMapper.selectCpsContentInfoById(user.getContentId());
        user.setDeptId(cpsContentInfo.getDeptId());
        user.setContentTitle(cpsContentInfo.getTitle());
        user.setUsrWechatId(loginUser.getUserId());
        cpsUsrApplyMapper.insertCpsUsrApplyOrUpdate(user);
    }

    @Override
    public void usrMeetingRegister(CpsUsrApply user) {
        List<CpsUsrApply> cpsUsrApplies = cpsUsrApplyMapper.selectCpsUsrApplyList(new CpsUsrApply() {{
            setTel(user.getTel());
            setApplyType(MeetingType.MEETING.getCode());
            setReviewState(ReviewStatus.PASS.getCode());
        }});
        if (CollectionUtils.isNotEmpty(cpsUsrApplies)) {
            throw new ServiceException("该手机号已经报名，请勿反复报名");
        }
        LoginUser loginUser = SecurityUtils.getLoginUser();
        user.setUpdateBy(loginUser.getUsername());
        user.setReviewState(ReviewStatus.WAIT.getCode());
        user.setUsrWechatId(loginUser.getUserId());
        user.setApplyType(MeetingType.MEETING.getCode());
        user.setDeptId(appCfg.getRoleTopDeptId());
        if (SysYesNo.YES.getCode().equals(user.getConferenceFlag()) && ObjectUtils.isNotEmpty(user.getContentId())) {
            CpsContentInfo cpsContentInfo = contentInfoMapper.selectCpsContentInfoById(user.getContentId());
            user.setContentTitle(cpsContentInfo.getTitle());
        }
        if (SysYesNo.YES.getCode().equals(user.getThemeFlag())&& ObjectUtils.isNotEmpty(user.getThemeId())) {
            CpsContentInfo cpsContentInfo = contentInfoMapper.selectCpsContentInfoById(user.getThemeId());
            user.setThemeTitle(cpsContentInfo.getTitle());
        }
        user.setFollowsJson(JSON.toJSONString(user.getFollows()));
        user.setConferenceRel(null);
        user.setReviewMsg("");

        cpsUsrApplyMapper.insertCpsUsrApplyOrUpdate(user);
    }

    @Override
    public List<CpsContentInfo> qryUsrCollectContent(String openId, String keyword) {
        return cpsMeetingUsrMapper.qryUsrCollectContent(openId, keyword);
    }

    @Override
    public String importUser(List<CpsMeetingUsr> userList, Boolean isUpdateSupport, String operName) {
        if (StringUtils.isNull(userList) || userList.size() == 0) {
            throw new ServiceException("导入用户数据不能为空！");
        }
        int successNum = 0;
        int failureNum = 0;
        StringBuilder successMsg = new StringBuilder();
        StringBuilder failureMsg = new StringBuilder();
        for (CpsMeetingUsr user : userList) {
            try {
                // 验证是否存在这个用户
                Integer cnt = cpsMeetingUsrMapper.exitUser(user.getTel());
                if (cnt < 1) {
                    BeanValidators.validateWithException(validator, user);
                    user.setCreateBy(operName);
                    cpsMeetingUsrMapper.insertCpsMeetingUsr(user);
                    successNum++;
                } else if (isUpdateSupport) {
                    BeanValidators.validateWithException(validator, user);
                    user.setUpdateBy(operName);
                    cpsMeetingUsrMapper.updateCpsMeetingUsrByTel(user);
                    successNum++;
                } else {
                    failureNum++;
                    failureMsg.append("<br/>" + failureNum + "、账号 " + user.getTel() + " 已存在");
                }
            } catch (Exception e) {
                failureNum++;
                log.info("导入用户失败：%s" , e.getMessage());
                failureMsg.append(e.getMessage());
            }
        }
        if (failureNum > 0) {
            failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据格式不正确，错误如下：");
            throw new ServiceException(failureMsg.toString());
        } else {
            successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条");
        }
        return successMsg.toString();
    }

    @Override
    public CpsMeetingEnterpriseTripInfo qryUsrTripContent(String openId) {
        CpsMeetingUsr cpsMeetingUsr = cpsMeetingUsrMapper.selectCpsMeetingUsrByOpenId(openId);
        if (ObjectUtils.isEmpty(cpsMeetingUsr)) {
            return null;
        }
        return cpsMeetingTripService.selectCpsMeetingEnterpriseTripInfoById(cpsMeetingUsr.getTripId());
    }
}
